@@ -30,7 +30,7 @@ use constant DEBUG => 0;
 use vars qw(@ISA $AUTOLOAD %CONSTANT_TAGS $VERSION);
 @ISA = qw(Bio::DB::Das::Chado::Segment Bio::SeqFeatureI
           Bio::Root::Root);
-$VERSION = 0.34;
+$VERSION = 0.35;
 
 %CONSTANT_TAGS = ();
 
@@ -168,7 +168,7 @@ new value of organism (to set)
 
 sub organism {
     my $self = shift;
-    my $organism = shift if defined(@_);
+    my $organism = shift;
     return $self->{'organism'} = $organism if defined($organism);
 
     #if it isn't passed in, we need to try to go get it
@@ -1647,6 +1647,8 @@ sub asString {
 #  return join '/',$id,$type,$self->SUPER::asString;
 }
 
+*as_string = \&asString;
+
 =head2 synonyms()
 
  Title   : synonyms
